@@ -1,16 +1,10 @@
-from . import sessions
-import json
+from .lib import loadLibrary
 from .response import Response
-from .utils import pull_from_mem
+from . import sessions
 import ctypes
+import json
 
-globalLibrary = None
-
-
-def load_library(path_to_lib):
-    global globalLibrary
-    globalLibrary = ctypes.cdll.LoadLibrary(path_to_lib)
-    print("Library Loaded Successfully")
+globalLibrary = loadLibrary()
 
 
 def get(url: str, **kwargs) -> Response:
@@ -29,4 +23,5 @@ def put(url: str, **kwargs) -> Response:
 
 
 def session(proxy="") -> sessions.Session:
+
     return sessions.Session(proxy, library=globalLibrary)
